% A part of the Matlab - Matisse interface
% Version 0.7 (July 2001)
%
% Miscellaneous functions
%
%   This part consists of the following functions, ordered by theme.
%   Functions marked with a '~' are not implemented yet.
%
%  Error Handling.
%
%  Each MATISSE function returns a status. The status MUST be tested whenever a 
%  MATISSE function is called. The functions MtFailure and MtSuccess test 
%  respectively the failure or the success of the operation. The functions
%  MtError and MtPError provide additional information on the error.
%
% The programmer can generate his own errors using the function MtMakeUserError. 
% He can therefore associate a specific value and a string with the error code 
% which is always MATISSE_USERERROR.
%
% ~ MtCheckErrorP  
% ~ MtError  
% ~ MtFailure  
% ~ MtGetUserError  
% ~ MtMakeUserError   
% ~ MtPError  
% ~ MtSuccess  
%
%  Dates & Times
%
%  The C API contains several functions to deal with date/time values.
%
% ~ MtTimeAdd  
% ~ MtTimeCompare  
% ~ MtTimeDiff  
% ~ MtTimeExtract  
% ~ MtTimeIntervalAdd 
% ~ MtTimeIntervalCompare 
% ~ MtTimeIntervalDiv 
% ~ MtTimeIntervalExtract 
% ~ MtTimeIntervalMul 
% ~ MtTimeIntervalPrint 
% ~ MtTimeIntervalSub 
% ~ MtTimePrint 
% ~ MtTimeSub 
%
%  Print Function
%
%  The function MtPrint prints an object, whatever its type.
%
%   MtPrint  
%
%  Locks
%
%  Explicit locks let you have a more accurate control over the objects that are 
%  manipulated. You can, for example, set a lock on several objects simultaneously.
%
% ~ MtLockNumObjects (MtSize numObjects, 
% ~ MtLockObjects (MtSize numObjects, 
% ~ MtLockObjectsFromEntryPoint (MtLock lock, 
%
%  Save Times
%
%  The function MtCommitTransaction lets you associate a string with the logical 
%  time that results. You can later use this string to identify the logical time 
%  that you want to consult later in version access. A state that can be consulted 
%  is indicated by a string. You can get the list of all the states that can be 
%  consulted using MtOpenVersionStream, and browse through it with MtNextVersion.
%
% ~ MtNextVersion   
% ~ MtOpenVersionStream 
%
%  Memory Management
%
%  Within a transaction, the client cache can grow disproportionately if the user 
%  is handling numerous objects. MATISSE offers the possibility to free objects 
%  from the client cache.
%
% ~ MtFreeNumObjects   
% ~ MtFreeObjects  
%
%  Debugging
%
%  In a debugging environment, two functions prove to be very useful:
%
% ~ MtDebugInitialize   - associates one service function with multiple C functions
% ~ MtDebugResetContext - is to be used when the context is inconsistent  
%
%  User Information 
%
%  It may prove useful for users to associate an object with a value that is managed
%  by the users themselves. This association object-value is maintained at the client
%  level only (the value is not saved in the database at commit time).
%  The association is valid during the connection.
%
% ~ MtInitUserField        - enables you to associate values in a user field
% ~ MtClearUserField       - clears all the object-value associations for a field
% ~ MtGetUserFieldValue    - retrieves the value in a specific field
% ~ MtRemoveUserFieldValue - remove the association object-value for a field
% ~ MtSetUserFieldValue    - associate a value with the field of an object
%
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@wins.uva.nl>
