% A part of the Matlab - Matisse interface
% Version 0.7 (July 2001)
%
% Database Reading.
%
% Once an object is loaded or read, the value of the object is located in the client
% cache: using this value or extracting the value of object properties does not
% generate server access. Loading an object does not imply loading the successors of
% the object.
%
%   This part consists of the following functions, ordered by theme.
%   Functions marked with a '~' are not implemented yet.
%
%  Schema Access.
%
%  Any schema object can be accessed via entry-points, via loops on the class
%  instances, or through navigation among objects.
%  However, MATISSE offers quick functions that grant direct access to the objects.
%
%   MtGetAttribute      - returns the key to an attribute of a given name
%   MtGetClass          - returns the key to a class of a given name
%   MtGetClassAttribute - returns the key to an attribute of a given name and class
%   MtGetIndex          - returns the key to an index of a given name  
% ~ MtGetMessage  
%   MtGetRelationship   - returns the key to a relationship of a given name
%
%  Object Description.
%
%  You can obtain specific information on any MATISSE object. Specifically, you can
%  determine: its class, and the relation the original meta-schema and superclasses 
%
%   MtGetObjectClass     - returns the class of the object
%   MtOpenAttributeStream - initializes the stream of all attributes of one object
%   MtOpenInverseRelationshipsStream - initializes the stream of inverse relatinships
%   MtOpenRelationshipsStream - initializes the stream of relationships
% ~ MtIsPredefinedObject 
%   MtIsInstanceOf - determines if the object is an instance of the given class
%
%  Properties an Object
%
%  The possible properties of an object are those defined by the object class 
%  (and its superclasses), as well as the inverse properties of the relationships
%  for which the class is a valid successor.
%
% ~ MtGetDimension  
%   MtGetListElements - retrieves a subset of the list value of the attribute 
%   MtGetValue  - returns the value of an attribute. This can be the default value. 
%   MtGetSuccessors - returns a list of all the objects that are successors  
%   MtOpenSuccessorsStream - initializes the stream of successors  
%   MtGetPredecessors - returns a list of all the objects that are predecessors 
%   MtOpenPredecessorsStream - initializes the stream of predecessors 
%
%  Loading Object
%
%  When accessing an attribute or a relationship part of an object, that part is
%  automatically loaded into the client cache. In addition, it is possible to load 
%  explicitly objects in the client cache. Once the objects are loaded, no server 
%  access is performed to obtain information on these objects.
%
% ~ MtLoadNumObjects  
% ~ MtLoadObjects  
%
%  Entry Points Access
%
%  An entry point enables you to access an instance by means of the value of one of
%  its properties. For a specific attribute, which is specified as entry point,
%  any instance can be accessed through one or more keywords (strings) computed from 
%  the value of the attribute. This feature lets you search quickly for instances
%  based on specific indexing.
%
% ~ MtGetObjectsFromEntryPoint
%
%  Index Access
%
%  Indexes allow access to an object stream. An index is defined by one up to a 
%  maximum of four criteria, attributes that are attached to the same class.
%  The values of the criteria may be ordered in ascending or in descending order. 
%  If an attribute is multiple valued (i.e. a list) for an object, there will be
%  multiple entries for this object in the index.
%
% ~ MtOpenIndexEntriesStream 
% ~ MtOpenIndexObjectsStream 
% ~ MtNextIndexEntry  
%   MtNextObject              - returns the next object in a stream
% ~ MtNextObjects  
%
%  Modified Successors
%
%  MATISSE provides some functions that give the list of all the successors either
%  added or removed to/from an object through a specific relationship, since the 
%  beginning of a transaction.
%
% ~ MtGetAddedSuccessors 
% ~ MtGetRemovedSuccessors 
%
%  Service Functions
%
%  Methods are service functions with a certain number of arguments. 
%  The number and type of arguments have to be checked carefully.
%
% ~ MtCallIfServiceFunction 
% ~ MtCallServiceFunction 
% ~ MtCallServiceFunctionFromName 
% ~ MtCheckAttribute 
% ~ MtCheckInstance 
% ~ MtCheckProperty 
% ~ MtCheckRelationship 
% ~ MtInitialize  
% ~ MtSend   
% ~ MtSendSuper  
%
%
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@wins.uva.nl>
