% MtOpenEntryPointStream initialize the stream of objects accessed by a entry point
%
%   [status, stream] = MtOpenEntryPointStream (entryPoint, ...
%                                         dictionaryKey, classKey, nbObjectsPerCall);
%   [status, stream] = MtOpenEntryPointStream (entryPoint, ...
%                                       dictionaryName, className, nbObjectsPerCall);
%
%   This function initializes the entry point stream of objects. 
%   The function MtNextObject (or MtNextObjects) uses the stream to 
%   provide the user with the instances selected on basis of the first  
%   three arguments.
%
%   An entry point enables you to access an instance by means of the value of one of 
%   its properties. When an entry function is specified for a specific dictionary,
%   any instance for which the dictionary's value has been assigned can be accessed 
%   through one or more keywords (strings) computed from the value of the dictionary. 
%   This feature lets you search quickly for instances based on specific indexing.
%
%   Adjusting the value of the nbObjectsPerCall argument allows you to tune the  
%   maximum response time for further calls to MtNextObject(s) functions. The  
%   greater the value is, the shorter is the overall enumeration.
%
%   OUTPUT [2]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      stream: number
%          An entry point stream.
%
%   INPUT [4]
%
%      entryPoint: string
%          An entry-point value.
%
%      class: number or string
%          The key or the name of a class. May be set to NULL. 
%
%      dictionary: number or string
%           The key or the name of a dictionary.
%
%      nbObjectsPerCall: number
%          This argument allow you to specify the maximum number of instances that 
%          will be retrieved at each server call. 
%
%   See also: 
%      GetObjectsFromEntryPoint
%      MtCloseStream
%      MtNextObject
%
%   Example:
%
% title = 'Titanic';
% conn = MtCurrentConnection;
%
% if ~conn
%    [status, conn] = MtAllocateConnection;
%    status = MtConnectDatabase (conn, 'amelie', 'Video501');
%    status = MtSetCurrentConnection (conn);
% end
%
% status = MtStartVersionAccess;
%
% [status, stream] = MtOpenEntryPointStream (title,'MovieTitle', 'Movie', 1);
% [status, instance1] = MtNextObject (stream);
% status = MtCloseStream (stream);
%
% [status, type, typesize] = ...
%     MtGetValue (instance1, 'Category', 1, 0, 0, 1, 0);
% [status, type, category, typesize] = ...
%     MtGetValue (instance1, 'Category', type, 1, 0, typesize, 0);
%
% sprintf('The movie %s is a %s\n', title, category)
% status = MtEndVersionAccess;
%
% status = MtNoCurrentConnection;
% status = MtDisconnectDatabase (conn);
% status = MtFreeConnection (conn);


%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

