% MtSQLGetColumnInfo returns the column type and name for a given column
% of a SQL selection from a Matisse database.
%
%   [status, colType, colName, nameLength] = ...
%         MtSQLGetColumnInfo (selection, colNum, nameLength)
%
%   INPUT [3]
%      selection: scalar
%         This scalar is a pointer to the selection produced by the successful
%         execution of a SQL SELECT statement.
%      colNum: scalar
%         Column number starts at 1.
%      nameLength: scalar
%         The maximal length of the colName string.
%   OUTPUT [1-4]
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise 'MATISSE_INVALARG' is returned.
%      colType: 1xn array of char
%          The column type. 
%      colName: 1xn array of char
%          The column name
%      nameLength: scalar
%         The actual length of the colName string.
%           
%   Example:
%
%   colnum = 1;
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%
%   [status, stmt] = MtSQLAllocStmt;
%   [status, stmt] = MtSQLExecDirect (stmt, 'SELECT * FROM Movie');
%
%   [status, selection] = MtGetSelection;
%   
%   [status, coltype, colname, namelen] = ...
%         MtSQLGetColumnInfo (selection, colnum, 256);
%   
%   while strcmp (status, 'MATISSE_SUCCESS');
%
%        colname
%        colnum = colnum + 1;
%        [status, coltype, colname, namelen] = ...
%              MtSQLGetColumnInfo (selection, colnum, 256);
%   end
%   
%   status = MtSQLFreeStmt (stmt);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

