% MtSetConnectionOption sets a connection option to other values than default.
%
%   [status] = MtSetConnectionOption (connection, option, value);
%
%   Connection options affect the way you can interact with the database. 
%   These options can only be changed when the connection to the database is  
%   not opened yet.
%
%   You can specify different values for the following options:
%
%    MT_DATA_ACCESS_MODE. This option allows you to specify the type of access 
%    that you intend to use when connecting to the database. 
%    Possible values are: 
%         MT_DATA_READONLY allows read only access to the data objects and to 
%         the schema. Any attempt to start a transaction will fail (only 
%         MtStartVersionAccess is allowed). 
%         MT_DATA_MODIFICATION allows read/write access to the data objects and 
%         read only access to the schema. This is the default mode. 
%         MT_DATA_DEFINITION allows read/write access to the data objects and to 
%         the schema. The first two access modes optimize the access to the schema.  
%         The DATA_DEFINITION access mode must be used only when schema or 
%         meta-schema updates are necessary. This option can not be changed when 
%         the connection to the database is opened. 
%    MT_LOCK_WAIT_TIME. This option allows to specify the amount of time the server
%    waits for access conflicts to be resolved; if the time expires, the explicit or
%    implicit lock request is rejected. The possible values are: 
%         MT_NO_WAIT: If the lock cannot immediately be granted, it is released 
%         immediately. 
%         MT_WAIT_FOREVER: The server waits until there is a deadlock or until the
%         lock is granted. This is the default. 
%         A positive integer of type MtLockWaitTime: The time (in seconds) that the
%         server waits for the lock to be granted. If the time expires, the lock 
%         request is rejected. If a deadlock occurs, the transaction fails or the
%         lock request is rejected (explicit locks, requested for example through  
%         MtLockObjects, do not cause a transaction to fail). 
%         When multiple objects are requested, the wait time applies to each object  
%         request individually. Wait time affects the process of obtaining locks for  
%         reads and writes within transactions. Object version requests are affected  
%         neither by locks nor by wait times. 
%    MT_SERVER_EXECUTION_PRIORITY. This option allows you to specify the priority of  
%    the requests that the connection will send to the database server. The higher  
%    it is the faster the requests will be executed. The possible values are: 
%         MT_MIN_SERVER_EXECUTION_PRIORITY. This is the default. 
%         MT_NORMAL_SERVER_EXECUTION_PRIORITY 
%         MT_ABOVE_NORMAL_SERVER_EXECUTION_PRIORITY 
%         MT_MAX_SERVER_EXECUTION_PRIORITY. 
%    MT_LOCKING_POLICY. This option allows you to specify which policy to use  
%    when access conflicts have to be resolved. The possible values are: 
%         MT_DEFAULT_ACCESS. 
%         MT_ACCESS_FOR_UPDATE. 
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise one of the following strings is returned.
%    MATISSE_INVALOP            - function is not allowed in this context (state)
%    MATISSE_INVALPRIO          - priority should be between 0 and x
%    MATISSE_INVALWAITTIME      - wait must be greater or equal to -1
%    MATISSE_INVALCONNECTOPTION - option > 3 are not a valid connection options
%    MATISSE_INVALCONNECTION    - a wrong argument, may be a non allocated connection
%
%   INPUT [3]
%
%      connection: number
%          The pointer to the structure that contains all the information 
%          about the connection to the database.
%           
%      option: number or string
%          The connection option to be set. Possible values are: 
%               'MT_SERVER_EXECUTION_PRIORITY' or 0
%               'MT_LOCK_WAIT_TIME' or 1
%               'MT_DATA_ACCESS_MODE' or 2
%               'MT_LOCKING_POLICY' or 3
%      value: number or string
%          The range of the value is option specific. See above for a full 
%          description.
%
%   See also: 
%      MtConnectDatabase
%      MtDisconnectDatabase
%      MtGetConnectionOption

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

